//! Secure Digital cards driver for [Drone STM32].
//!
//! [Drone STM32]: https://github.com/drone-os/drone-stm32

#![feature(const_fn)]
#![feature(generators)]
#![feature(never_type)]
#![feature(prelude_import)]
#![feature(proc_macro_gen)]
#![no_std]
#![warn(missing_docs)]
#![doc(html_root_url = "https://docs.rs/drone-sd-stm32/0.2.2")]
#![cfg_attr(test, feature(alloc))]
#![cfg_attr(test, feature(allocator_api))]
#![cfg_attr(test, feature(allocator_internals))]
#![cfg_attr(test, default_lib_allocator)]
#![cfg_attr(feature = "cargo-clippy", allow(precedence))]

#[cfg(test)]
extern crate alloc;
#[macro_use]
extern crate drone_core;
extern crate drone_sd_core;
extern crate drone_stm32 as drone_plat;
extern crate futures;
#[cfg(test)]
extern crate test;

mod sd_spi_sess;

pub use sd_spi_sess::{SdSpiSessPlat, SdSpiSessResPlat};

#[prelude_import]
#[allow(unused_imports)]
use drone_plat::prelude::*;

#[cfg(test)]
drone_core::heap! {
  struct Heap;
  size = 0x40000;
  pools = [
    [0x4; 0x4000],
    [0x20; 0x800],
    [0x100; 0x100],
    [0x800; 0x20],
  ];
}

#[cfg(test)]
#[global_allocator]
static mut GLOBAL: Heap = Heap::new();
